@@ -219,17 +219,17 @@ def generate_and_write_rsa_keypair(filepath=None, bits=DEFAULT_RSA_KEY_BITS,
   # Write the public key (i.e., 'public', which is in PEM format) to
   # '<filepath>.pub'.  (1) Create a temporary file, (2) write the contents of
   # the public key, and (3) move to final destination.
-  file_object = securesystemslib.util.TempFile()
+  file_object = tempfile.TemporaryFile()
   file_object.write(public.encode('utf-8'))
   # The temporary file is closed after the final move.
-  file_object.move(filepath + '.pub')
+  securesystemslib.util.persist_temp_file(file_object, filepath + '.pub')
 
   # Write the private key in encrypted PEM format to '<filepath>'.
   # Unlike the public key file, the private key does not have a file
   # extension.
-  file_object = securesystemslib.util.TempFile()
+  file_object = tempfile.TemporaryFile()
   file_object.write(private.encode('utf-8'))
-  file_object.move(filepath)
+  securesystemslib.util.persist_temp_file(file_object, filepath)
 
   return filepath
 
@@ -355,7 +355,7 @@ def import_rsa_privatekey_from_file(filepath, password=None,
 
 
 
-def import_rsa_publickey_from_file(filepath):
+def import_rsa_publickey_from_file(filepath, scheme='rsassa-pss-sha256'):
   """
   <Purpose>
     Import the RSA key stored in 'filepath'.  The key object returned is in the
@@ -366,6 +366,9 @@ def import_rsa_publickey_from_file(filepath):
     filepath:
       <filepath>.pub file, an RSA PEM file.
 
+    scheme:
+      The signature scheme used by the imported key.
+
   <Exceptions>
     securesystemslib.exceptions.FormatError, if 'filepath' is improperly
     formatted.
@@ -386,6 +389,9 @@ def import_rsa_publickey_from_file(filepath):
   # Raise 'securesystemslib.exceptions.FormatError' if there is a mismatch.
   securesystemslib.formats.PATH_SCHEMA.check_match(filepath)
 
+  # Is 'scheme' properly formatted?
+  securesystemslib.formats.RSA_SCHEME_SCHEMA.check_match(scheme)
+
   # Read the contents of the key file that should be in PEM format and contains
   # the public portion of the RSA key.
   with open(filepath, 'rb') as file_object:
@@ -393,7 +399,8 @@ def import_rsa_publickey_from_file(filepath):
 
   # Convert 'rsa_pubkey_pem' to 'securesystemslib.formats.RSAKEY_SCHEMA' format.
   try:
-    rsakey_dict = securesystemslib.keys.import_rsakey_from_public_pem(rsa_pubkey_pem)
+    rsakey_dict = securesystemslib.keys.import_rsakey_from_public_pem(
+        rsa_pubkey_pem, scheme)
 
   except securesystemslib.exceptions.FormatError as e:
     raise securesystemslib.exceptions.Error('Cannot import improperly formatted'
@@ -483,7 +490,7 @@ def generate_and_write_ed25519_keypair(filepath=None, password=None):
 
   # Create a temporary file, write the contents of the public key, and move
   # to final destination.
-  file_object = securesystemslib.util.TempFile()
+  file_object = tempfile.TemporaryFile()
 
   # Generate the ed25519 public key file contents in metadata format (i.e.,
   # does not include the keyid portion).
@@ -499,11 +506,11 @@ def generate_and_write_ed25519_keypair(filepath=None, password=None):
   # '<filepath>.pub'.  (1) Create a temporary file, (2) write the contents of
   # the public key, and (3) move to final destination.
   # The temporary file is closed after the final move.
-  file_object.move(filepath + '.pub')
+  securesystemslib.util.persist_temp_file(file_object, filepath + '.pub')
 
   # Write the encrypted key string, conformant to
   # 'securesystemslib.formats.ENCRYPTEDKEY_SCHEMA', to '<filepath>'.
-  file_object = securesystemslib.util.TempFile()
+  file_object = tempfile.TemporaryFile()
 
   # Encrypt the private key if 'password' is set.
   if len(password):
@@ -517,7 +524,7 @@ def generate_and_write_ed25519_keypair(filepath=None, password=None):
   # Raise 'securesystemslib.exceptions.CryptoError' if 'ed25519_key' cannot be
   # encrypted.
   file_object.write(ed25519_key.encode('utf-8'))
-  file_object.move(filepath)
+  securesystemslib.util.persist_temp_file(file_object, filepath)
 
   return filepath
 
@@ -738,7 +745,7 @@ def generate_and_write_ecdsa_keypair(filepath=None, password=None):
 
   # Create a temporary file, write the contents of the public key, and move
   # to final destination.
-  file_object = securesystemslib.util.TempFile()
+  file_object = tempfile.TemporaryFile()
 
   # Generate the ECDSA public key file contents in metadata format (i.e., does
   # not include the keyid portion).
@@ -753,16 +760,16 @@ def generate_and_write_ecdsa_keypair(filepath=None, password=None):
   # Write the public key (i.e., 'public', which is in PEM format) to
   # '<filepath>.pub'.  (1) Create a temporary file, (2) write the contents of
   # the public key, and (3) move to final destination.
-  file_object.move(filepath + '.pub')
+  securesystemslib.util.persist_temp_file(file_object, filepath + '.pub')
 
   # Write the encrypted key string, conformant to
   # 'securesystemslib.formats.ENCRYPTEDKEY_SCHEMA', to '<filepath>'.
-  file_object = securesystemslib.util.TempFile()
+  file_object = tempfile.TemporaryFile()
   # Raise 'securesystemslib.exceptions.CryptoError' if 'ecdsa_key' cannot be
   # encrypted.
   encrypted_key = securesystemslib.keys.encrypt_key(ecdsa_key, password)
   file_object.write(encrypted_key.encode('utf-8'))
-  file_object.move(filepath)
+  securesystemslib.util.persist_temp_file(file_object, filepath)
 
   return filepath
 
